@@ -7,16 +7,22 @@ OC.L10N.register(
     "Select all" : "Označi sve",
     "New" : "Novo",
     "New folder" : "Nova fascikla",
+    "Rename folder" : "Preimenuj fasciklu",
+    "Delete folder" : "Izbriši fasciklu",
     "Cancel" : "Otkaži",
+    "Shared with you" : "Shared with you",
+    "Files" : "Datoteke",
     "Import" : "Uvoz",
     "Export" : "Izvezi",
     "Title" : "Naslov",
     "Link" : "Veza",
     "Notes" : "Notes",
+    "Open file" : "Otvori Datoteku",
     "Owner" : "Vlasnik",
     "Sharing" : "Dijeljenje",
     "Share link" : "Podijelite vezu",
     "Allow editing" : "Dozvolite izmjenu",
+    "Allow resharing" : "Dopustite ponovno dijeljenje",
     "Folder" : "Fasikla",
     "Save" : "Spremi"
 },
