@@ -6,37 +6,37 @@ OC.L10N.register(
     "Unsupported file type for import" : "Tipo de archivo no soportado para importar",
     "Details" : "Detalles",
     "Rename" : "Renombrar",
+    "Copy link" : "Copiar liga",
     "Move" : "Mover",
     "Delete" : "Borrar",
+    "Select all" : "Seleccionar todo",
+    "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
-    "Grid view" : "Vista de cuadrícula",
-    "List view" : "Vista de lista",
-    "Select all" : "Seleccionar todo",
+    "Add a bookmark" : "Agregar un marcador",
+    "Delete folder" : "Borrar carpeta",
+    "Choose folder" : "Seleccioanr carpeta",
     "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "Recent" : "Reciente",
-    "Add a bookmark" : "Agregar un marcador",
+    "Shared with you" : "Compartido con usted",
+    "Files" : "Archivos",
     "Import" : "Importar",
     "Export" : "Exportar",
-    "Recently added" : "Agregado recientemente",
-    "Alphabetically" : "Alfabéticamente",
-    "Last modified" : "Última modificación",
     "Bookmarklet" : "Marcador a código ",
-    "Clear data" : "Borrar datos",
     "Title" : "Título",
     "Link" : "Liga",
     "Tags" : "Etiquetas",
     "Notes" : "Notas",
+    "Open file" : "Abrir archivo",
     "Owner" : "Dueño",
     "Sharing" : "Compartiendo",
     "Share link" : "Compartir liga",
-    "Copy link" : "Copiar liga",
     "Allow editing" : "Permitir edición",
-    "Select" : "Seleccionar",
+    "Allow resharing" : "Permitir volver a compartir",
     "Privacy" : "Privacidad",
     "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Quieres sobreescribirlo?",
     "Folder" : "Carpeta",
     "Save" : "Guardar"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
