@@ -34,6 +34,8 @@ OC.L10N.register(
     "Select one or more tags" : "Pasirinkite vieną ar daugiau žymių",
     "New" : "Nauja",
     "New folder" : "Naujas aplankas",
+    "Change to grid view" : "Keisti į tinklelio rodinį",
+    "Change to list view" : "Keisti į sąrašo rodinį",
     "RSS feed copied" : "RSS kanalas nukopijuotas",
     "Enter a link" : "Įveskite nuorodą",
     "Add a bookmark" : "Pridėti adresyno įrašą",
@@ -65,7 +67,6 @@ OC.L10N.register(
     "Tags" : "Žymės",
     "Notes" : "Pastabos",
     "Open file" : "Atverti failą",
-    "Projects" : "Projektai",
     "Owner" : "Savininkas",
     "Sharing" : "Bendrinimas",
     "Select a user or group" : "Pasirinkti naudotoją ar grupę",
@@ -76,6 +77,7 @@ OC.L10N.register(
     "Allow editing" : "Leisti redaguoti",
     "Allow resharing" : "Leisti bendrinti iš naujo",
     "Remove share" : "Šalinti viešinį",
+    "Projects" : "Projektai",
     "Link copied" : "Nuoroda nukopijuota",
     "Privacy" : "Privatumas",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Adresynas bandys apsilankyti jūsų pridedamose internetinėse svetainėse, kad automatiškai pridėtų informaciją apie jas.",
