@@ -6,7 +6,11 @@ OC.L10N.register(
     "Delete" : "ئۆچۈر",
     "New" : "يېڭى",
     "New folder" : "يېڭى قىسقۇچ",
+    "Rename folder" : "قىسقۇچ ئاتىنى ئۆزگەرت",
+    "Delete folder" : "قىسقۇچ ئۆچۈر",
     "Cancel" : "ۋاز كەچ",
+    "Shared with you" : "Shared with you",
+    "Files" : "ھۆججەتلەر",
     "Import" : "ئەكىر",
     "Export" : "چىقار",
     "Title" : "ماۋزۇ",
